@@ -1,13 +1,12 @@
 """Controller holding and managing HUE resources that are of the config type."""
-from __future__ import annotations
-
-from typing import TYPE_CHECKING, Type, Union
+from typing import TYPE_CHECKING, Optional, Type, Union
 
 from ...util import mac_from_bridge_id
 from ..models.bridge import Bridge
 from ..models.bridge_home import BridgeHome
 from ..models.device import Device
-from ..models.entertainment import Entertainment, EntertainmentConfiguration
+from ..models.entertainment import Entertainment
+from ..models.entertainment_configuration import EntertainmentConfiguration
 from ..models.resource import ResourceTypes
 from .base import BaseResourcesController, GroupedControllerBase
 
@@ -19,9 +18,10 @@ class BridgeController(BaseResourcesController[Type[Bridge]]):
     """Controller holding and managing HUE resources of type `bridge`."""
 
     item_type = ResourceTypes.BRIDGE
+    item_cls = Bridge
 
     @property
-    def id(self) -> str | None:
+    def id(self) -> Optional[str]:
         """Return id of the only/first bridge found in items."""
         for item in self.items:
             return item.id
@@ -32,12 +32,14 @@ class BridgeHomeController(BaseResourcesController[Type[BridgeHome]]):
     """Controller holding and managing HUE resources of type `bridge_home`."""
 
     item_type = ResourceTypes.BRIDGE_HOME
+    item_cls = BridgeHome
 
 
 class EntertainmentController(BaseResourcesController[Type[Entertainment]]):
     """Controller holding and managing HUE resources of type `entertainment`."""
 
     item_type = ResourceTypes.ENTERTAINMENT
+    item_cls = Entertainment
 
 
 class EntertainmentConfigurationController(
@@ -46,6 +48,7 @@ class EntertainmentConfigurationController(
     """Controller holding and managing HUE resources of type `entertainment_configuration`."""
 
     item_type = ResourceTypes.ENTERTAINMENT_CONFIGURATION
+    item_cls = EntertainmentConfiguration
 
 
 class ConfigController(
