@@ -1,10 +1,8 @@
 """Controller holding and managing HUE resources of type `device`."""
-from __future__ import annotations
+from typing import List, Optional, Type
 
-from typing import List, Type
-
-from ..models.connectivity import ZigbeeConnectivity
-from ..models.device import Device
+from ..models.zigbee_connectivity import ZigbeeConnectivity
+from ..models.device import Device, DevicePut
 from ..models.feature import IdentifyFeature
 from ..models.light import Light
 from ..models.resource import ResourceTypes
@@ -17,6 +15,7 @@ class DevicesController(BaseResourcesController[Type[Device]]):
     """Controller holding and managing HUE resources of type `device`."""
 
     item_type = ResourceTypes.DEVICE
+    item_cls = Device
 
     def get_lights(self, id: str) -> List[Light]:
         """Return all lights belonging to given device."""
@@ -32,11 +31,11 @@ class DevicesController(BaseResourcesController[Type[Device]]):
             if x in self._bridge.sensors
         ]
 
-    def get_room(self, id: str) -> Room | None:
+    def get_room(self, id: str) -> Optional[Room]:
         """Return room the given device belongs to (if any)."""
         return next((x for x in self._bridge.groups.room if id in x.devices), None)
 
-    def get_zigbee_connectivity(self, id: str) -> ZigbeeConnectivity | None:
+    def get_zigbee_connectivity(self, id: str) -> Optional[ZigbeeConnectivity]:
         """Return the ZigbeeConnectivity resource connected to device."""
         for service in self._items[id].services:
             if service.rtype == ResourceTypes.ZIGBEE_CONNECTIVITY:
@@ -53,4 +52,4 @@ class DevicesController(BaseResourcesController[Type[Device]]):
         - Lights perform one breathe cycle
         - Sensors perform LED identification cycles for 15 seconds
         """
-        await self.update(id, Device(id, identify=IdentifyFeature()))
+        await self.update(id, DevicePut(identify=IdentifyFeature()))
